{ lib, pkgs, config,  ... }:
let
  cfg = config.myServices.websites.nassime.production;
  varDir = "/var/lib/ftp/nassime";
  env = config.myEnv.websites.nassime;
  domain = "nassime.bouya.org";
in {
  options.myServices.websites.nassime.production.enable = lib.mkEnableOption "enable Nassime's website";

  config = lib.mkIf cfg.enable {
    services.webstats.sites = [ { name = domain; } ];

    security.acme.certs."ftp".extraDomains."${domain}" = null;

    services.websites.env.production.vhostConfs.nassime = {
      certName     = "nassime";
      certMainHost = domain;
      hosts        = [ domain ];
      root         = varDir;
      extraConfig  = [
        ''
        Use Stats ${domain}
        ServerAdmin ${env.server_admin}

        <Directory ${varDir}>
          DirectoryIndex index.htm index.html
          Options Indexes FollowSymLinks MultiViews Includes
          AllowOverride None
          Require all granted
        </Directory>
          ''
      ];
    };
  };
}
