{ callPackage, mylibs, composerEnv, lib }:
rec {
  adminer = callPackage ./adminer {};
  apache-theme = callPackage ./apache-theme {};
  awl = callPackage ./awl {};
  davical = callPackage ./davical {};
  diaspora = callPackage ./diaspora { inherit mylibs; };

  dokuwiki = callPackage ./dokuwiki { inherit mylibs; };
  dokuwiki-with-plugins = dokuwiki.withPlugins (builtins.attrValues dokuwiki-plugins);
  dokuwiki-plugins = let
    names = [ "farmer" "todo" ];
  in
    lib.attrsets.genAttrs names
      (name: callPackage (./dokuwiki/plugins + "/${name}.nix") {});

  etherpad-lite = callPackage ./etherpad-lite {};

  grocy = callPackage ./grocy { inherit mylibs composerEnv; };

  infcloud = callPackage ./infcloud {};

  mantisbt_2 = callPackage ./mantisbt_2 {};
  mantisbt_2-with-plugins = mantisbt_2.withPlugins (builtins.attrValues mantisbt_2-plugins);
  mantisbt_2-plugins = let
    names = [ "slack" "source-integration" ];
  in
    lib.attrsets.genAttrs names
      (name: callPackage (./mantisbt_2/plugins + "/${name}") {});

  mastodon = callPackage ./mastodon { inherit mylibs; };

  mediagoblin = callPackage ./mediagoblin { inherit mylibs; };
  mediagoblin-with-plugins = mediagoblin.withPlugins (builtins.attrValues mediagoblin-plugins);
  mediagoblin-plugins = let
    names = [ "basicsearch" ];
  in
    lib.attrsets.genAttrs names
      (name: callPackage (./mediagoblin/plugins + "/${name}") {});

  nextcloud = callPackage ./nextcloud {};

  peertube = callPackage ./peertube { inherit mylibs; };
  phpbb = callPackage ./phpbb {};

  phpldapadmin = callPackage ./phpldapadmin {};
  rompr = callPackage ./rompr { inherit mylibs; };

  roundcubemail = callPackage ./roundcubemail {};
  roundcubemail-with-plugins-skins = roundcubemail.withPlugins (builtins.attrValues roundcubemail-plugins) (builtins.attrValues roundcubemail-skins);
  roundcubemail-skins = let
    names = [];
  in
    lib.attrsets.genAttrs names
      (name: callPackage (./roundcubemail/skins + "/${name}") {});
  roundcubemail-plugins = let
    names = [
      "automatic_addressbook" "carddav" "contextmenu"
      "contextmenu_folder" "html5_notifier" "ident_switch"
      "message_highlight" "thunderbird_labels"
    ];
  in
    lib.attrsets.genAttrs names
      (name: callPackage (./roundcubemail/plugins + "/${name}") { buildPlugin = roundcubemail.buildPlugin; });

  spip = callPackage ./spip {};

  surfer = callPackage ./surfer { inherit mylibs; };
  taskwarrior-web = callPackage ./taskwarrior-web { inherit mylibs; };

  ttrss = callPackage ./ttrss { inherit mylibs; };
  ttrss-with-plugins = ttrss.withPlugins (builtins.attrValues ttrss-plugins);
  ttrss-plugins = let
    names = [ "auth_ldap" "af_feedmod" "feediron" "ff_instagram" "tumblr_gdpr_ua" ];
    patched = [ "af_feedmod" "feediron" ];
  in
    lib.attrsets.genAttrs names
      (name: callPackage (./ttrss/plugins + "/${name}") (
        { inherit mylibs; } //
        (if builtins.elem name patched then { patched = true; } else {})
        )
      );

  wallabag = callPackage ./wallabag { inherit composerEnv; };
  yourls = callPackage ./yourls { inherit mylibs; };
  yourls-with-plugins = yourls.withPlugins (builtins.attrValues yourls-plugins);
  yourls-plugins = let
    names = [ "ldap" ];
  in
    lib.attrsets.genAttrs names
      (name: callPackage (./yourls/plugins + "/${name}") { inherit mylibs; });
}
